django-tornado-websockets
=========================

.. image:: https://travis-ci.org/Kocal/django-tornado-websockets.svg?branch=master
    :target: https://travis-ci.org/Kocal/django-tornado-websockets

.. image:: https://coveralls.io/repos/github/Kocal/django-tornado-websockets/badge.svg?branch=master
    :target: https://coveralls.io/github/Kocal/django-tornado-websockets?branch=master

.. image:: https://badge.fury.io/py/django-tornado-websockets.svg
    :target: https://badge.fury.io/py/django-tornado-websockets

Django-tornado-websockets is a useful solution to provide an easy way to use Tornado WebSockets with a Django
application.

Supported versions
------------------

======  ======
Python  Django
======  ======
2.7     1.8
3.3     1.9
3.4
3.5
======  ======

Documentation
-------------

Documentation is available on Read the Docs:

- Stable: http://django-tornado-websockets.readthedocs.io/en/stable/
- Latest: http://django-tornado-websockets.readthedocs.io/en/latest/
- Develop: http://django-tornado-websockets.readthedocs.io/en/develop/

But also on my own server: http://docs.kocal.fr/django-tornado-websockets/
